<?php
/**
 * Orders
 *
 * Shows orders on the account page.
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/myaccount/orders.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	https://docs.woocommerce.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 3.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

do_action( 'woocommerce_before_account_orders', $has_orders ); ?>

<?php if ( $has_orders ) : ?>

	<div class="table-responsive">

		<table class="table table-bordered table-striped vert-align-middle woocommerce-orders-table woocommerce-MyAccount-orders shop_table shop_table_responsive my_account_orders account-orders-table">
			<thead>
				<tr>
					<?php foreach ( wc_get_account_orders_columns() as $column_id => $column_name ) : ?>
						<th class="woocommerce-orders-table__header woocommerce-orders-table__header-<?php echo esc_attr( $column_id ); ?>"><span class="nobr"><?php echo esc_html( $column_name ); ?></span></th>
					<?php endforeach; ?>
				</tr>
			</thead>

			<tbody>
				<?php foreach ( $customer_orders->orders as $customer_order ) :
					$order      = wc_get_order( $customer_order );
					$item_count = $order->get_item_count();
					?>
					<tr class="woocommerce-orders-table__row woocommerce-orders-table__row--status-<?php echo esc_attr( $order->get_status() ); ?> order">
						<?php foreach ( wc_get_account_orders_columns() as $column_id => $column_name ) : ?>
							<td class="woocommerce-orders-table__cell woocommerce-orders-table__cell-<?php echo esc_attr( $column_id ); ?>" data-title="<?php echo esc_attr( $column_name ); ?>">
								<?php if ( has_action( 'woocommerce_my_account_my_orders_column_' . $column_id ) ) : ?>
									<?php do_action( 'woocommerce_my_account_my_orders_column_' . $column_id, $order ); ?>

								<?php elseif ( 'order-number' === $column_id ) : ?>
									<a href="<?php echo esc_url( $order->get_view_order_url() ); ?>">
										<?php echo _x( '#', 'hash before order number', 'basicstore' ) . $order->get_order_number(); ?>
									</a>

								<?php elseif ( 'order-date' === $column_id ) : ?>
									<time datetime="<?php echo esc_attr( $order->get_date_created()->date( 'c' ) ); ?>"><?php echo esc_html( wc_format_datetime( $order->get_date_created() ) ); ?></time>

								<?php elseif ( 'order-status' === $column_id ) : ?>
									<?php echo esc_html( wc_get_order_status_name( $order->get_status() ) ); ?>

								<?php elseif ( 'order-total' === $column_id ) : ?>
									<?php
									/* translators: 1: formatted order total 2: total order items */
									printf( _n( '%1$s for %2$s item', '%1$s for %2$s items', $item_count, 'basicstore' ), $order->get_formatted_order_total(), $item_count );
									?>

								<?php elseif ( 'order-actions' === $column_id ) : ?>
									<?php
										$actions = array(
											'pay'    => array(
												'url'  => $order->get_checkout_payment_url(),
												'name' => __( 'Pay', 'basicstore' ),
												'btn-class' => 'btn-primary' ,

											),
											'view'   => array(
												'url'  => $order->get_view_order_url(),
												'name' => __( 'View', 'basicstore' ),
												'btn-class' => 'btn-info',
											),
											'cancel' => array(
												'url'  => $order->get_cancel_order_url( wc_get_page_permalink( 'myaccount' ) ),
												'name' => __( 'Cancel', 'basicstore' ),
												'btn-class' => 'btn-warning',
											)
										);

										if ( ! $order->needs_payment() ) {
											unset( $actions['pay'] );
										}

										if ( ! in_array( $order->get_status(), apply_filters( 'woocommerce_valid_order_statuses_for_cancel', array( 'pending', 'failed' ), $order ) ) ) {
											unset( $actions['cancel'] );
										}

										if ( $actions = apply_filters( 'woocommerce_my_account_my_orders_actions', $actions, $order ) ) {
											foreach ( $actions as $key => $action ) {
												echo '<a href="' . esc_url( $action['url'] ) . '" class="btn btn-sm woocommerce-button button '  . sanitize_html_class( $key ) .' '. sanitize_html_class( $action['btn-class'] ) . '">' . esc_html( $action['name'] ) . '</a>';
											}
										}
									?>
								<?php endif; ?>
							</td>
						<?php endforeach; ?>
					</tr>
				<?php endforeach; ?>
			</tbody>
		</table>

	</div><!-- .table-responsive -->

	<?php do_action( 'woocommerce_before_account_orders_pagination' ); ?>

	<?php if ( 1 < $customer_orders->max_num_pages ) : ?>

		<ul class="pager woocommerce-pagination woocommerce-pagination--without-numbers woocommerce-Pagination">

			<?php if ( 1 !== $current_page ) : ?>
				<li class=""><a class="woocommerce-button woocommerce-button--previous woocommerce-Button woocommerce-Button--previous button" href="<?php echo esc_url( wc_get_endpoint_url( 'orders', $current_page - 1 ) ); ?>"><span aria-hidden="true">&larr;</span> <?php _e( 'Previous', 'basicstore' ); ?></a></li>
			<?php endif; ?>

			<?php if ( intval( $customer_orders->max_num_pages ) !== $current_page ) : ?>
				<li class=""><a class="woocommerce-button woocommerce-button--next woocommerce-Button woocommerce-Button--next button" href="<?php echo esc_url( wc_get_endpoint_url( 'orders', $current_page + 1 ) ); ?>"><?php _e( 'Next', 'basicstore' ); ?> <span aria-hidden="true">&rarr;</span></a></li>
			<?php endif; ?>

		</ul>

	<?php endif; ?>

<?php else : ?>
	<p class="woocommerce-message woocommerce-message--info woocommerce-Message woocommerce-Message--info woocommerce-info alert alert-warning" role="alert">
		<?php _e( 'No order has been made yet.', 'basicstore' ); ?>
	</p>

	<p><a class="woocommerce-Button button btn btn-default" href="<?php echo esc_url( apply_filters( 'woocommerce_return_to_shop_redirect', wc_get_page_permalink( 'shop' ) ) ); ?>">
		<span class="glyphicon glyphicon-chevron-left" aria-hidden="true"></span>
		<?php _e( 'Go shop', 'basicstore' ) ?>
	</a></p>

<?php endif; ?>

<?php do_action( 'woocommerce_after_account_orders', $has_orders ); ?>
